'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _cheerio = require('cheerio');

var _cheerio2 = _interopRequireDefault(_cheerio);

var _babelCore = require('babel-core');

var babel = _interopRequireWildcard(_babelCore);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var babelOptions = {
  presets: [require.resolve('babel-preset-mcs-lite')],
  babelrc: false
};

var compile = function compile(code) {
  return babel.transform(code, babelOptions).code;
};

var parseSVG = function parseSVG(xml) {
  var $ = _cheerio2.default.load(xml, { xmlMode: true });
  $('path[fill="none"]').remove();
  return {
    viewBox: $('svg').attr('viewBox'),
    children: $('svg').html()
  };
};

var template = function template(componentName, _ref) {
  var children = _ref.children,
      viewBox = _ref.viewBox;
  return '\nimport React from \'react\';\nimport PropTypes from \'prop-types\';\n\nclass ' + componentName + ' extends React.Component {\n  render() {\n    const { size, children, ...otherProps } = this.props;\n\n    return (\n      <svg\n        viewBox="' + viewBox + '"\n        preserveAspectRatio="xMidYMid meet"\n        fill="currentColor"\n        width={size}\n        height={size}\n        {...otherProps}\n      >\n        ' + children + '\n        {children}\n      </svg>\n    );\n  }\n}\n\n' + componentName + '.displayName = \'' + componentName + '\';\n' + componentName + '.propTypes = {\n  size: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),\n  children: PropTypes.node,\n};\n' + componentName + '.defaultProps = {\n  size: \'1em\',\n};\nexport default ' + componentName + ';\n';
};

exports.default = { parseSVG: parseSVG, template: template, compile: compile };
module.exports = exports['default'];